from src.dbdisk.database.database_service import DatabaseService
class DatabaseSybaseService(DatabaseService):
    def __init__(self, connection_string):
        super().__init__(connection_string)

    def connect(self):
        import pymssql
        return pymssql.connect(self.connection_string)

    def handle_error(self, error):
        super().handle_error(error)



from setuptools import setup, find_packages

setup(
    name='omnijp',
    version='2.5.0',
    packages=find_packages(),
    install_requires=[
        'retry>=0.9.2',
        'requests>=2.31.0',
        'pymssql>=2.3.0',
        'psycopg2>=2.9.9',
        'openai~=1.30.5'
    ],
    entry_points={
        'console_scripts': [
            # Add any command-line scripts here
        ],
    }
)



from src.dbdisk.caches.db_disk_cache_csv import DbDiskCacheCsv
from src.dbdisk.types import DiskFileType


class DbDiskFactory:
    @staticmethod
    def create_db_disk(disk_file_type, cache_dir, cache_name, can_zip=False, rows_per_file=1000000):
        match disk_file_type:
            case DiskFileType.CSV:
                return DbDiskCacheCsv(cache_dir, cache_name,can_zip, rows_per_file)
            case DiskFileType.JSON:
                raise NotImplementedError
            case DiskFileType.XML:
                raise NotImplementedError
            case _:
                return None

